MinBadgeWrapper class

Envuelve un child y superpone un MinBadge en la position indicada.

Útil para notificaciones sobre íconos o avatares.

MinBadgeWrapper(
  label: const Text('3'),
  variant: MinBadgeVariant.destructive,
  position: MinBadgePosition.topRight,
  child: MinButton(
    variant: MinButtonVariant.ghost,
    child: const Icon(TablerIcons.bell),
    onPressed: () {},
  ),
)
Inheritance

Constructors

MinBadgeWrapper({Key? key, required Widget label, required Widget child, MinBadgeVariant variant = MinBadgeVariant.primary, MinBadgePosition position = MinBadgePosition.topRight, Offset? offset, Widget? icon, BoxDecoration? badgeDecoration})
const

Properties

badgeDecoration BoxDecoration?
Decoración personalizada para el badge superpuesto.
final
child Widget
Widget base sobre el que se posiciona el badge.
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
Icono opcional dentro del badge.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label Widget
Contenido del badge superpuesto.
final
offset Offset?
Desplazamiento adicional desde la esquina.
final
position MinBadgePosition
Esquina donde se ubica el badge.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant MinBadgeVariant
Variante visual del badge.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited