MinButtonVariant enum

Variantes visuales de MinButton.

  • primary: fondo sólido con el color primary del tema.
  • secondary: fondo atenuado con el color secondary.
  • outline: solo borde, sin fondo.
  • ghost: sin fondo ni borde, solo texto.
Inheritance
Available extensions

Values

primary → const MinButtonVariant
secondary → const MinButtonVariant
outline → const MinButtonVariant
ghost → const MinButtonVariant

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MinButtonVariant>
A constant List of the values in this enum, in order of their declaration.