MinButtonGroupOption<T> class

Representa una opción individual dentro de un MinButtonGroup.

Contiene el valor de la opción y si está habilitada.

Constructors

MinButtonGroupOption({required T value, bool enabled = true})
Crea una opción para MinButtonGroup.
const

Properties

enabled bool
Si es false, la opción está deshabilitada y no responde a taps.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
Valor único que identifica esta opción.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited