MinCard class
Tarjeta reutilizable con fondo, borde y sombra predefinidos.
Usa los tokens card y cardForeground del tema por defecto.
Se adapta automáticamente al tema claro/oscuro.
Uso básico
MinCard(
child: Text('Contenido de la tarjeta'),
)
Con margin y padding personalizado
MinCard(
margin: EdgeInsets.all(16),
padding: EdgeInsets.all(24),
child: Text('Tarjeta con espaciado personalizado'),
)
Colors personalizados
MinCard(
backgroundColor: theme.colors.primary,
borderColor: theme.colors.primary,
child: Text('Tarjeta con colores personalizados',
style: TextStyle(color: theme.colors.primaryForeground)),
)
- Inheritance
Constructors
-
MinCard({Key? key, required Widget child, Color? backgroundColor, Color? borderColor, BorderRadiusGeometry? borderRadius, List<
BoxShadow> ? shadows, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, double? width, double? height, BoxConstraints? constraints}) -
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- child → Widget
-
final
- constraints → BoxConstraints?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadows
→ List<
BoxShadow> ? -
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited