MinCheckbox class

Checkbox con toggle, soporte de teclado y personalización de icono.

Se usa para selección de una o más opciones de un conjunto. Soporta navegación por teclado (espacio/enter) y personalización completa del icono de verificación.

Uso básico

MinCheckbox(
  value: _isSelected,
  onChanged: (value) => setState(() => _isSelected = value),
)

Con icono personalizado

MinCheckbox(
  value: _isSelected,
  onChanged: (value) => setState(() => _isSelected = value),
  checkIcon: Icon(Icons.check, size: 14),
)
Inheritance

Constructors

MinCheckbox({Key? key, required bool value, ValueChanged<bool>? onChanged, MinCheckboxSize size = MinCheckboxSize.md, bool disabled = false, FocusNode? focusNode, bool autofocus = false, Color? side, Color? checkColor, Widget? checkIcon, CustomPainter? checkPainter, String? semanticLabel})
const

Properties

autofocus bool
final
checkColor Color?
final
checkIcon Widget?
final
checkPainter CustomPainter?
final
disabled bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
side Color?
final
size MinCheckboxSize
final
value bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MinCheckbox>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited