MinDrawerController class

Controlador de visibilidad de los paneles de MinDrawer.

Permite abrir, cerrar y alternar los drawers de inicio y final de programación. Notifica a los listeners cuando el estado cambia.

final controller = MinDrawerController();
controller.openDrawer();    // Abre el drawer izquierdo
controller.openEndDrawer(); // Abre el drawer derecho
controller.closeAll();      // Cierra ambos
Inheritance

Constructors

MinDrawerController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDrawerOpen bool
no setter
isEndDrawerOpen bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
closeAll() → void
closeDrawer() → void
closeEndDrawer() → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
openDrawer() → void
openEndDrawer() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggleDrawer() → void
toggleEndDrawer() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited