MinScaffold class

Andamiaje de página con app bar, body, bottom bar, FAB y drawers.

Maneja automáticamente el padding de la status bar, la barra de navegación del sistema y el teclado. Cuando el teclado aparece, el body se desplaza hacia arriba para que los inputs siempre sean visibles.

Uso básico

MinScaffold(
  appBar: MinAppBar(title: Text('Mi App')),
  body: Text('Contenido'),
)

Con drawer

MinScaffold(
  appBar: MinAppBar(title: Text('Mi App')),
  drawer: Text('Menú lateral'),
  body: Text('Contenido'),
)
Inheritance

Constructors

MinScaffold({Key? key, required Widget body, Widget? appBar, Widget? floatingActionButton, Widget? bottomNavigationBar, double bottomNavigationBarHeight = 64, Widget? drawer, Widget? endDrawer, MinDrawerController? drawerController, double drawerWidth = 280, double endDrawerWidth = 280, double edgeDragWidth = 24, bool enableDrawerGestures = true, bool persistentDrawerOnWide = true, double persistentDrawerBreakpoint = 960, Color drawerOverlayColor = const Color(0x52000000), Color? drawerBackgroundColor, Color? endDrawerBackgroundColor, Duration drawerDuration = const Duration(milliseconds: 180), Curve drawerCurve = Curves.easeOut, Color? backgroundColor, bool resizeToAvoidBottomInset = true})
const

Properties

appBar Widget?
final
backgroundColor Color?
final
body Widget
final
bottomNavigationBar Widget?
final
bottomNavigationBarHeight double
final
drawer Widget?
final
drawerBackgroundColor Color?
final
drawerController MinDrawerController?
final
drawerCurve Curve
final
drawerDuration Duration
final
drawerOverlayColor Color
final
drawerWidth double
final
edgeDragWidth double
final
enableDrawerGestures bool
final
endDrawer Widget?
final
endDrawerBackgroundColor Color?
final
endDrawerWidth double
final
floatingActionButton Widget?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
persistentDrawerBreakpoint double
final
persistentDrawerOnWide bool
final
resizeToAvoidBottomInset bool
Si es true, el body se desplaza hacia arriba cuando el teclado aparece, asegurando que los inputs siempre sean visibles. Por defecto es true.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited