searchable property
When true, the dropdown shows a search input that filters options
by their MinSelectOption.label.
Implementation
final bool searchable;
When true, the dropdown shows a search input that filters options
by their MinSelectOption.label.
final bool searchable;