MinSelectOption<T> class
A concrete option inside a MinSelect dropdown.
- Inheritance
-
- Object
- MinSelectItem<
T> - MinSelectOption
Constructors
- MinSelectOption({required T value, required String label, bool enabled = true, Widget? leading, Widget? trailing})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited