MinSelectSection<T> class
A non-selectable section header rendered inside the dropdown.
When the dropdown is searchable, sections are hidden while the user types.
- Inheritance
-
- Object
- MinSelectItem<
T> - MinSelectSection
Constructors
- MinSelectSection({required String label})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited