MinTabsOption<T> class

Opción individual dentro de MinTabs.

Constructors

MinTabsOption({required T value, required Widget label, Widget? icon, bool disabled = false})
const

Properties

disabled bool
Si true la opción no es interactuable.
final
hashCode int
The hash code for this object.
no setteroverride
icon Widget?
Icono opcional mostrado antes del label.
final
label Widget
Widget de etiqueta (normalmente un Text).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
Valor asociado a esta opción.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override