MinTooltip class

Tooltip flotante que aparece al hacer hover (desktop/web) o al mantener presionado (mobile).

Usa el sistema de floating (MinFloatingBase) para posicionarse automáticamente respecto al child y renderizarse en un Overlay.

Uso básico

MinTooltip(
  message: 'Esto es un tooltip',
  child: Text('Hover o long-press aquí'),
)

Delay personalizado

MinTooltip(
  message: 'Aparece instantáneamente',
  delay: Duration.zero,
  child: Text('Target'),
)

Posición personalizada

MinTooltip(
  message: 'Tooltip arriba',
  side: MinUiAnchorSide.above(),
  child: Text('Target'),
)
Inheritance

Constructors

MinTooltip({Key? key, required Widget child, required String message, Duration delay = const Duration(milliseconds: 500), MinUiAnchorSide? side, Duration? duration, Duration? reverseDuration, Curve? curve, MinFloatingAnimation? animation, EdgeInsetsGeometry? padding, BorderRadiusGeometry? borderRadius, Color? backgroundColor, TextStyle? textStyle})
const

Properties

animation MinFloatingAnimation?
final
backgroundColor Color?
final
borderRadius BorderRadiusGeometry?
final
child Widget
final
curve Curve?
final
delay Duration
final
duration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message String
final
padding EdgeInsetsGeometry?
final
reverseDuration Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side MinUiAnchorSide?
final
textStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MinTooltip>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited