buildContent abstract method
Override in subclasses to build the floating panel content.
Implementation
Widget buildContent(BuildContext context, MinFloatingController controller);
Override in subclasses to build the floating panel content.
Widget buildContent(BuildContext context, MinFloatingController controller);