MinFloatingController class
Controls the open/closed state of any floating component (Popover, Tooltip, Dropdown, Sheet, Select, Dialog…).
Can be owned by the component itself or externally by the caller.
Usage:
final controller = MiniFloatingController();
controller.show();
controller.hide();
controller.toggle();
// Listen to changes:
controller.addListener(() { ... });
// Read state:
if (controller.isOpen) { ... }
- Inheritance
-
- Object
- ChangeNotifier
- MinFloatingController
Constructors
- MinFloatingController({bool isOpen = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isClosed → bool
-
no setter
- isOpen → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
hide(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setOpen(
bool open) → void -
show(
) → void -
toggle(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited