MinMotion class

Constructors

MinMotion({Duration fast = const Duration(milliseconds: 100), Duration normal = const Duration(milliseconds: 200), Duration slow = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut})
const

Properties

curve Curve
final
fast Duration
final
hashCode int
The hash code for this object.
no setteroverride
low Duration
no setter
normal Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slow Duration
final

Methods

copyWith({Duration? fast, Duration? normal, Duration? slow, Curve? curve}) MinMotion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

defaults → const MinMotion