MinRadiusScale class

Constructors

MinRadiusScale({double none = 0, double sm = 6, double md = 8, double lg = 10, double xl = 12, double xl2 = 16, double full = 9999})
const

Properties

full double
final
hashCode int
The hash code for this object.
no setteroverride
lg double
final
md double
final
none double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
final
xl double
final
xl2 double
final

Methods

copyWith({double? none, double? sm, double? md, double? lg, double? xl, double? xl2, double? full}) MinRadiusScale
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

defaults → const MinRadiusScale