MinShadows class

Constructors

MinShadows({required List<BoxShadow> sm, required List<BoxShadow> md, required List<BoxShadow> lg, required List<BoxShadow> xl, required List<BoxShadow> xl2})
const
MinShadows.defaultShadows()
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
lg List<BoxShadow>
final
md List<BoxShadow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm List<BoxShadow>
final
xl List<BoxShadow>
final
xl2 List<BoxShadow>
final

Methods

copyWith({List<BoxShadow>? sm, List<BoxShadow>? md, List<BoxShadow>? lg, List<BoxShadow>? xl, List<BoxShadow>? xl2}) MinShadows
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

defaults → const MinShadows