MinButton class

Botón con variantes, tamaños, estados de loading y soporte de teclado.

Soporta.leading/trailing widgets, animaciones de hover/press, y navegación por teclado (espacio/enter).

Uso básico

MinButton(
  onPressed: () => print('Tap'),
  child: Text('Click me'),
)

Variante secundaria con leading

MinButton(
  variant: MinButtonVariant.secondary,
  leading: Icon(TablerIcons.plus),
  onPressed: () {},
  child: Text('Crear'),
)

Estado de loading

MinButton(
  onPressed: _handleSubmit,
  loading: _isLoading,
  child: Text('Enviar'),
)
Inheritance

Constructors

MinButton({Key? key, required Widget child, VoidCallback? onPressed, MinButtonVariant variant = MinButtonVariant.primary, MinButtonSize size = MinButtonSize.md, Widget? leading, Widget? trailing, bool loading = false, bool disabled = false, FocusNode? focusNode, bool autofocus = false, String? semanticLabel, BorderRadius? borderRadius})
const

Properties

autofocus bool
final
borderRadius BorderRadius?
Border radius personalizado. Sobreescribe el valor por defecto del tema según el size.
final
child Widget
final
disabled bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
final
loading bool
final
onPressed VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
size MinButtonSize
final
trailing Widget?
final
variant MinButtonVariant
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MinButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited