MinDatePicker class
Selector de fecha con popover, calendario mensual y selector de meses.
Muestra un trigger con la fecha seleccionada o un placeholder. El popover contiene un calendario con navegación mensual, un botón "Hoy" para ir a la fecha actual, y un botón "Meses" para cambiar al selector de meses. Al seleccionar un mes se vuelve al calendario.
Se adapta automáticamente al tema claro/oscuro.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MinDatePicker
Constructors
Properties
- disabled → bool
-
Si es
true, el selector está deshabilitado y no responde a taps.final - firstDate → DateTime?
-
Fecha mínima seleccionable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDate → DateTime?
-
Fecha inicial mostrada en el calendario al abrir.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastDate → DateTime?
-
Fecha máxima seleccionable.
final
-
onChanged
→ ValueChanged<
DateTime> -
Callback cuando se selecciona una fecha.
final
- placeholder → String?
-
Texto mostrado cuando no hay fecha seleccionada.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Etiqueta accesibilidad del componente.
final
- value → DateTime?
-
Fecha seleccionada actualmente.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MinDatePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited