MinDrawer class
Layout con drawers izquierdo y derecho.
Soporta gestos de deslizamiento desde los bordes de la pantalla, overlay que cierra el drawer al tocar, y modo persistente en pantallas anchas (el drawer queda visible junto al contenido).
Uso básico
MinDrawer(
drawer: Text('Menú lateral'),
child: Text('Contenido principal'),
)
Con controller explícito
final controller = MinDrawerController();
MinDrawer(
controller: controller,
drawer: Text('Menú'),
child: Text('Contenido'),
)
// controller.openDrawer() para abrir programáticamente
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MinDrawer
Constructors
- MinDrawer({Key? key, required Widget child, Widget? drawer, Widget? endDrawer, MinDrawerController? controller, double drawerWidth = 280, double endDrawerWidth = 280, double edgeDragWidth = 24, bool enableGestures = true, bool persistentOnWide = true, double persistentBreakpoint = 960, Color overlayColor = const Color(0x52000000), Color? drawerBackgroundColor, Color? endDrawerBackgroundColor, String? drawerLabel, String? endDrawerLabel, bool enableEscape = true, Duration duration = const Duration(milliseconds: 180), Curve curve = Curves.easeOut})
-
const
Properties
- child → Widget
-
final
- controller → MinDrawerController?
-
final
- curve → Curve
-
final
- drawer → Widget?
-
final
- drawerBackgroundColor → Color?
-
final
- drawerLabel → String?
-
final
- drawerWidth → double
-
final
- duration → Duration
-
final
- edgeDragWidth → double
-
final
- enableEscape → bool
-
final
- enableGestures → bool
-
final
- endDrawer → Widget?
-
final
- endDrawerBackgroundColor → Color?
-
final
- endDrawerLabel → String?
-
final
- endDrawerWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- overlayColor → Color
-
final
- persistentBreakpoint → double
-
final
- persistentOnWide → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MinDrawer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited