MinInputStyle class
Constructors
- MinInputStyle({required BoxDecoration idle, required BoxDecoration focused, required BoxDecoration error, required BoxDecoration disabled, Color? foregroundColor, Color? disabledForegroundColor, Color? placeholderColor, EdgeInsets? contentPadding})
-
const
Properties
- contentPadding → EdgeInsets?
-
final
- disabled → BoxDecoration
-
final
- disabledForegroundColor → Color?
-
final
- error → BoxDecoration
-
final
- focused → BoxDecoration
-
final
- foregroundColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idle → BoxDecoration
-
final
- placeholderColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
filled(
MinThemeData theme) → MinInputStyle -
ghost(
MinThemeData theme) → MinInputStyle -
outline(
MinThemeData theme) → MinInputStyle -
underline(
MinThemeData theme) → MinInputStyle