MinFloatingDefaults class
Default values for all Min floating components. Override at the app level via MinFloatingConfig.
- Annotations
Constructors
- MinFloatingDefaults({Duration duration = const Duration(milliseconds: 140), Duration? reverseDuration, Curve curve = Curves.easeOut, Curve reverseCurve = Curves.easeIn, bool closeOnTapOutside = true, bool closeOnEscape = true, bool closeOnScroll = false, MinUiAnchorSide side = const MinUiAnchorSide.below(), Color barrierColor = const Color(0x00000000), bool useDimmedBarrier = false})
-
const
Properties
- barrierColor → Color
-
Barrier color behind the floating element (transparent by default).
final
- closeOnEscape → bool
-
Close when user presses Escape.
final
- closeOnScroll → bool
-
Close when the nearest scroll view scrolls.
final
- closeOnTapOutside → bool
-
Close when user taps outside the floating element.
final
- curve → Curve
-
final
- duration → Duration
-
Animation duration when opening.
final
- effectiveReverseDuration → Duration
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- reverseCurve → Curve
-
final
- reverseDuration → Duration?
-
Animation duration when closing (defaults to duration if null).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → MinUiAnchorSide
-
Default placement of floating elements relative to their trigger.
final
- useDimmedBarrier → bool
-
Use a dimmed (semi-opaque) barrier, like a modal dialog.
final
Methods
-
copyWith(
{Duration? duration, Duration? reverseDuration, Curve? curve, Curve? reverseCurve, bool? closeOnTapOutside, bool? closeOnEscape, bool? closeOnScroll, MinUiAnchorSide? side, Color? barrierColor, bool? useDimmedBarrier}) → MinFloatingDefaults -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited